{$if not def GRAPHICS_VIEW_H} CONST GRAPHICS_VIEW_H=0;

{ *****************************************************************
  ** KickPascal-Include-Datei "graphics/view.h" zu Kickstart 3.0 **
  ***************************************************************** }

TYPE p_ViewPort = ^ViewPort;
TYPE p_ColorMap = ^ColorMap;
TYPE p_RasInfo = ^RasInfo;
TYPE p_ViewExtra = ^ViewExtra;
TYPE p_View = ^View;
TYPE p_ViewPortExtra = ^ViewPortExtra;
TYPE p_PaletteExtra = ^PaletteExtra;
TYPE p_DBufInfo = ^DBufInfo;

{$if not def EXEC_SEMAPHORES_H;incl "exec/semaphores.h";endif}
{$if not def GRAPHICS_GFX_H;incl "graphics/gfx.h";endif}
{$if not def GRAPHICS_COPPER_H;incl "graphics/copper.h";endif}
{$if not def GRAPHICS_GFXNODES_H;incl "graphics/gfxnodes.h";endif}
{$if not def GRAPHICS_MONITOR_H;incl "graphics/monitor.h";endif}
{$if not def GRAPHICS_DISPLAYINFO_H;incl "graphics/displayinfo.h";endif}
{$if not def HARDWARE_CUSTOM_H;incl "hardware/custom.h";endif}
{$if not def UTILITY_TAGITEM_H;incl "utility/tagitem.h";endif}


TYPE ViewPort = RECORD
 Next             : p_ViewPort;
 ColorMap         : p_ColorMap;
 DspIns           : p_CopList;
 SprIns           : p_CopList;
 ClrIns           : p_CopList;
 UCopIns          : p_UCopList;
 DWidth           : Integer;
 DHeight          : Integer;
 DxOffset         : Integer;
 DyOffset         : Integer;
 Modes            : Word;
 SpritePriorities : Byte;
 ExtendedModes    : Byte;
 RasInfo          : p_RasInfo;
END;

TYPE View = RECORD
 ViewPort   : p_ViewPort;
 LOFCprList : p_cprlist;
 SHFCprList : p_cprlist;
 DyOffset   : Integer;
 DxOffset   : Integer;
 Modes      : Word;
END;

TYPE ViewExtra = RECORD
 n       : ExtendedNode;
 View    : p_View;
 Monitor : p_MonitorSpec;
 TopLine : Word;
END;

TYPE ViewPortExtra = RECORD
 n           : ExtendedNode;
 ViewPort    : p_ViewPort;
 DisplayClip : Rectangle;
 VecTable    : Ptr;
 DriverData  : ARRAY[0..1] of Ptr;
 Flags       : Word;
 Origin      : ARRAY[0..1] of Point;
END;

CONST
 VPXB_FREE_ME           = 0;
 VPXF_FREE_ME           = $1;
 VPXB_LAST              = 1;
 VPXF_LAST              = $2;
 VPXB_STRADDLES_256     = 4;
 VPXF_STRADDLES_256     = $10;
 VPXB_STRADDLES_512     = 5
 VPXF_STRADDLES_512     = $20;

 EXTEND_VSTRUCT         = $1000;

 VPF_A2024      = $40;
 VPF_TENHZ      = $20;
 VPB_A2024      = 6;
 VPB_TENHZ      = 4;


 GENLOCK_VIDEO   = $0002;
 LACE            = $0004;
 SUPERHIRES      = $0020;
 PFBA            = $0040;
 EXTRA_HALFBRITE = $0080;
 GENLOCK_AUDIO   = $0100;
 DUALPF          = $0400;
 HAM             = $0800;
 EXTENDED_MODE   = $1000;
 VP_HIDE         = $2000;
 SPRITES         = $4000;
 HIRES           = $8000;


TYPE RasInfo = RECORD
 Next     : p_RasInfo;
 BitMap   : p_BitMap;
 RxOffset : Integer;
 RyOffset : Integer;
END;

TYPE ColorMap = RECORD
 Flags             : Byte;
 _Type             : Byte;   { "_" ergnzt }
 Count             : Word;
 ColorTable        : Ptr;
 cm_vpe            : p_ViewPortExtra;
 TransparencyBits  : ^Word;
 TransparencyPlane : Byte;
 reserved1         : Byte;
 reserved2         : Word;
 cm_vp             : p_ViewPort;
 NormalDisplayInfo : Ptr;
 CoerceDisplayInfo : Ptr;
 cm_batch_items    : p_TagItem;
 VPModeID          : Long;
 PalExtra          : p_PaletteExtra;
 SpriteBase_Even   : Word;
 SpriteBase_Odd    : Word;
 Bp_0_base         : Word;
 Bp_1_base         : Word;
END;

CONST
 COLORMAP_TYPE_V1_2  = $00;
 COLORMAP_TYPE_V1_4  = $01;
 COLORMAP_TYPE_V36   = COLORMAP_TYPE_V1_4;
 COLORMAP_TYPE_V39   = $02;

CONST
 COLORMAP_TRANSPARENCY   = $01;
 COLORPLANE_TRANSPARENCY = $02;
 BORDER_BLANKING         = $04;
 BORDER_NOTRANSPARENCY   = $08;
 VIDEOCONTROL_BATCH      = $10;
 USER_COPPER_CLIP        = $20;
 BORDERSPRITES           = $40;

 CMF_CMTRANS    = 0;
 CMF_CPTRANS    = 1;
 CMF_BRDRBLNK   = 2;
 CMF_BRDNTRAN   = 3;
 CMF_BRDRSPRT   = 6;

 SPRITERESN_ECS = 0;

 SPRITERESN_140NS       = 1;
 SPRITERESN_70NS        = 2;
 SPRITERESN_35NS        = 3;
 SPRITERESN_DEFAULT     = -1;

 CMAB_FULLPALETTE       = 0;
 CMAF_FULLPALETTE       = $1;

TYPE PaletteExtra = RECORD
 pe_Semaphore   : SignalSemaphore;
 pe_FirstFree   : Word;
 pe_NFree       : Word;
 pe_FirstShared : Word;
 pe_NShared     : Word;
 pe_RefCnt      : ^Byte;
 pe_AllocList   : ^Byte;
 pe_ViewPort    : p_ViewPort;
 pe_SharableColors : Word;
end;

CONST
 PENB_EXCLUSIVE   = 0;
 PENB_NO_SETCOLOR = 1;

 PENF_EXCLUSIVE   = $1;
 PENF_NO_SETCOLOR = $2;

 PEN_EXCLUSIVE    = PENF_EXCLUSIVE;
 PEN_NO_SETCOLOR  = PENF_NO_SETCOLOR;

 PRECISION_EXACT        = -1;
 PRECISION_IMAGE        =  0;
 PRECISION_ICON         = 16;
 PRECISION_GUI          = 32;

 OBP_Precision = $84000000;
 OBP_FailIfBad = $84000001;

 MVP_OK         = 0;
 MVP_NO_MEM     = 1;
 MVP_NO_VPE     = 2;
 MVP_NO_DSPINS  = 3;
 MVP_NO_DISPLAY = 4;

 MCOP_OK        = 0;
 MCOP_NO_MEM    = 1;
 MCOP_NOP       = 2;

TYPE DBufInfo = RECORD
 dbi_Link1      : Ptr;
 dbi_Count1     : Long;
 dbi_SafeMessage: Message;
 dbi_UserData1  : Ptr;
 dbi_Link2      : Ptr;
 dbi_Count2     : Long;
 dbi_DispMessage: Message;
 dbi_UserData2  : Ptr;
 dbi_MatchLong  : Long;
 dbi_CopPtr1    : Ptr;
 dbi_CopPtr2    : Ptr;
 dbi_CopPtr3    : Ptr;
 dbi_BeamPos1   : Word;
 dbi_BeamPos2   : Word;
end;

{$endif}
